﻿using BPA.SAAS.KitChenManageOrder.Application.BaseDto;
using BPA.SAAS.KitChenManageOrder.Core;
using BPA.SAAS.KitChenManageOrder.Core.Entity;
using Furion.FriendlyException;
using Microsoft.AspNetCore.Http;
using Microsoft.AspNetCore.Mvc.Controllers;
using Microsoft.AspNetCore.Mvc.Filters;
using Newtonsoft.Json;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Threading.Tasks;

namespace BPA.SAAS.KitChenManageOrder.Web.Core.Handlers
{
    public class RequestAuditFiltercs : IAsyncActionFilter
    {
        private readonly CheckHandler _checkServices;

        public RequestAuditFiltercs()
        {
            _checkServices = new CheckHandler();
        }

        public async Task OnActionExecutionAsync(ActionExecutingContext context, ActionExecutionDelegate next)
        {

            CurrentUser.MessageId = Guid.NewGuid().ToString();

            //============== 这里是执行方法之前获取数据 ====================
            // 获取 HttpContext 和 HttpRequest 对象
            var httpContext = context.HttpContext;
            var httpRequest = httpContext.Request;

            // 获取客户端 Ipv4 地址
            var remoteIPv4 = httpContext.GetRemoteIpAddressToIPv4();

            // 获取请求的 Url 地址
            var requestUrl = httpRequest.GetRequestUrlAddress();

            // 获取来源 Url 地址
            var refererUrl = httpRequest.GetRefererUrlAddress();

            // 获取控制器、路由信息
            var actionDescriptor = context.ActionDescriptor as ControllerActionDescriptor;

            // 获取请求的方法
            var method = actionDescriptor.MethodInfo;

            // 获取请求参数（写入日志，需序列化成字符串后存储）
            var parameters = context.ActionArguments;

            //foreach (var parameter in parameters)
            //{
            //    var stingA = DtoValidator.GetSign(parameter.Value);
            //    var vvvv = stingA;
            //}

            if (requestUrl.ToUpper().Contains("ExternalPlatform".ToUpper()))
            {

                var key = httpRequest.Headers["key"];
                var sign = httpRequest.Headers["sign"];
                List<PropertyInfo> proplist = new List<PropertyInfo>();
                if(string.IsNullOrWhiteSpace(key)) throw Oops.Oh(ErrorCodeEnum.Code1005);
               // if (string.IsNullOrWhiteSpace(sign)) throw Oops.Oh(ErrorCodeEnum.Code1005);
                foreach (var parameter in parameters)
                {
                   // var stingA = DtoValidator.GetSign(parameter.Value);
                    //var sign = DtoValidator.GetAttributePrice(parameter.Value, "sign");
                    await _checkServices.CheckSign(key, "", sign);
                }
            }

            //============== 这里是执行方法之后获取数据 ====================
            var actionContext = await next();

            // 获取返回的结果
            var returnResult = actionContext.Result;

            // 判断是否请求成功，没有异常就是请求成功
            var isRequestSucceed = actionContext.Exception == null;
            if (requestUrl.ToUpper().Contains("ExternalPlatform".ToUpper()))
            {
                try
                {
                    //记录日志
                    await SqlSugarDb.Db.Insertable(new BPA_ThirdpartyreQuestLog()
                    {
                        Id = CurrentUser.MessageId,
                        CreateBy = DateTime.Now.ToString(),
                        GroupId = CurrentUser.GroupId,
                        RequestUrl = requestUrl,
                        ReauestMethod = httpRequest.Method,
                        ReauestParm = JsonConvert.SerializeObject(parameters),
                        ResultParm = !isRequestSucceed ? actionContext.Exception.ToString() : JsonConvert.SerializeObject(returnResult),
                        IP = remoteIPv4
                    }).ExecuteCommandAsync();
                }
                catch (Exception e)
                {
                }
            }

        }
    }
}
