﻿using BPA.SAAS.KitChenManageOrder.Core;
using BPA.SAAS.KitChenManageOrder.Web.Core.Handlers;
using FluentValidation.AspNetCore;
using Furion;
using Microsoft.AspNetCore.Builder;
using Microsoft.AspNetCore.Hosting;
using Microsoft.Extensions.DependencyInjection;
using Microsoft.Extensions.Hosting;
using Newtonsoft.Json;

namespace BPA.SAAS.KitChenManageOrder.Web.Core
{
    public class Startup : AppStartup
    {
        public void ConfigureServices(IServiceCollection services)
        {
            services.AddConsoleFormatter();
            services.AddJwt<JwtHandler>();
            services.AddRemoteRequest();
            services.AddControllersWithViews()
         .AddFluentValidation(fv =>
         {
             fv.RegisterValidatorsFromAssemblies(App.Assemblies);
         })
    .AddNewtonsoftJson(options =>
    {
        options.SerializerSettings.ReferenceLoopHandling = ReferenceLoopHandling.Ignore;
        options.SerializerSettings.DateFormatString = "yyyy-MM-dd HH:mm:ss";
    });
            services.AddCorsAccessor();
            services.AddSqlsugarSetup(App.Configuration);
            services.AddControllers()
                    .AddInjectWithUnifyResult();
            services.AddMvcFilter<RequestAuditFiltercs>();
        }

        public void Configure(IApplicationBuilder app, IWebHostEnvironment env)
        {
            if (env.IsDevelopment())
            {
                app.UseDeveloperExceptionPage();
            }

            app.UseHttpsRedirection();

            app.UseRouting();

            app.UseCorsAccessor();

            app.UseAuthentication();
            app.UseAuthorization();

            app.UseInject(string.Empty);

            app.UseEndpoints(endpoints =>
            {
                endpoints.MapControllers();
            });
        }
    }
}